@@ -1,3 +1,18 @@
+__license__ = """
+NML is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+NML is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along
+with NML; if not, write to the Free Software Foundation, Inc.,
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA."""
+
 from nml import expression, generic, nmlop
 
 constant_numbers = {
@@ -169,6 +184,9 @@ constant_numbers = {
     'CB_RESULT_ATTACH_ALLOW'               : 0xFE,
     'CB_RESULT_ATTACH_ALLOW_IF_RAILTYPES'  : 0xFF,
 
+    'CB_RESULT_NO_MORE_ARTICULATED_PARTS'  : 0xFF,
+    'CB_RESULT_REVERSED_VEHICLE'           : 0x80,
+
     'CB_RESULT_32_DAYS_TRIGGER'            : 0,
     'CB_RESULT_32_DAYS_COLOUR_MAPPING'     : 1,
 
@@ -423,6 +441,8 @@ constant_numbers = {
     'CB_RESULT_IND_ALLOW'               : 0x00,
     'CB_RESULT_IND_DISALLOW'            : 0x01,
 
+    'CB_RESULT_NO_TEXT'                 : 0xFF,
+
     'CB_RESULT_LOCATION_ALLOW'                        : 0x400,
     'CB_RESULT_LOCATION_DISALLOW'                     : 0x401,
     'CB_RESULT_LOCATION_DISALLOW_ONLY_RAINFOREST'     : 0x402,
